@@ -6,7 +6,7 @@
  */
 // [[Rcpp::export]]
 std::vector<bool> C_test_is_absorbing(arma::mat m){
-  hesim::ctstm::trans_mat tmat(m);
+  hesim::trans_mat tmat(m);
   return tmat.absorbing_;
 }
 
@@ -15,7 +15,7 @@ std::vector<bool> C_test_is_absorbing(arma::mat m){
  */
 // [[Rcpp::export]]
 std::vector<int> C_test_trans_mat_trans_id(arma::mat m, int from_state){
-  hesim::ctstm::trans_mat tmat(m);
+  hesim::trans_mat tmat(m);
   return tmat.trans_id(from_state);
 }
 
@@ -24,7 +24,7 @@ std::vector<int> C_test_trans_mat_trans_id(arma::mat m, int from_state){
  */
 // [[Rcpp::export]]
 std::vector<int> C_test_trans_mat_to(arma::mat m, int from_state){
-  hesim::ctstm::trans_mat tmat(m);
+  hesim::trans_mat tmat(m);
   return tmat.to(from_state);
 }
 
@@ -33,6 +33,6 @@ std::vector<int> C_test_trans_mat_to(arma::mat m, int from_state){
  */
 // [[Rcpp::export]]
 int C_test_trans_mat_n_trans(arma::mat m){
-  hesim::ctstm::trans_mat tmat(m);
+  hesim::trans_mat tmat(m);
   return tmat.n_trans_;
 }
