@@ -30,4 +30,11 @@ test_that("seq", {
                seq(2, -2.45, -.13))
   expect_error(hesim:::C_test_seq(0, -3, .1))
   expect_error(hesim:::C_test_seq(0, 3, -.1))
+})
+
+# Test c++ function max_lt -----------------------------------------------------
+test_that("max_lt", {
+  expect_equal(hesim:::C_test_max_lt(seq(0, 10), 5), 5)
+  expect_equal(hesim:::C_test_max_lt(seq(0, 10), 5.1), 5)
+  expect_equal(hesim:::C_test_max_lt(seq(0, 10), Inf), 10)
 })
\ No newline at end of file
