@@ -63,8 +63,11 @@ msfit_list <- flexsurvreg_list(msfit_list)
 
 ## Joint
 data("ebmt4")
-tmat_ebmt4 <- transMat(x = list(c(2, 3, 5, 6), c(4, 5, 6), c(4, 5, 6), c(5, 6),
-                c(), c()), names = c("Tx", "Rec", "AE", "Rec+AE", "Rel", "Death"))
+tmat_ebmt4 <- transMat(
+  x = list(c(2, 3, 5, 6), c(4, 5, 6), c(4, 5, 6), c(5, 6),
+          c(), c()), 
+  names = c("Tx", "Rec", "AE", "Rec+AE", "Rel", "Death")
+)
 msebmt <- msprep(data = ebmt4, trans = tmat_ebmt4, time = c(NA, "rec", "ae",
                  "recae", "rel", "srv"), status = c(NA, "rec.s", "ae.s", "recae.s",
                   "rel.s", "srv.s"), keep = c("match", "proph", "year", "agecl"))
@@ -96,15 +99,21 @@ disprog <- data.frame(sample = sample,
                       time_stop = time_stop)
 
 stprob_fun <- function(time){
-  data.table(hesim:::C_ctstm_indiv_stateprobs(disprog, t = time, n_samples = 2,
-                                              n_strategies = 2, 
-                                              unique_strategy_id = unique(strategy_id),
-                                              strategy_index = c(rep(0, 5), rep(1, 4), rep(0, 2), rep(1, 2)),
-                                              n_grps = 1,
-                                              unique_grp_id = 1,
-                                              grp_index = rep(0, 13),
-                                              n_states = 3,
-                                              n_patients = 2))
+  data.table(
+    hesim:::C_ctstm_indiv_stateprobs(
+      disprog, 
+      t = time, 
+      n_samples = 2,
+      n_strategies = 2, 
+      unique_strategy_id = unique(strategy_id),
+      strategy_index = c(rep(0, 5), rep(1, 4), rep(0, 2), rep(1, 2)),
+      n_grps = 1,
+      unique_grp_id = 1,
+      grp_index = rep(0, 13),
+      n_states = 3,
+      n_patients = 2
+    )
+  )
 }
 
 
@@ -131,6 +140,44 @@ test_that("C_ctstm_indiv_stateprobs", {
   expect_equal(stprobs[sample == 0 & state_id == 2 & strategy_id == 3, prob], .5)
 })
 
+# Create transition model ------------------------------------------------------
+# Transition specific models
+msfit_list_data <- expand(hesim_dat)
+
+test_that("create_IndivCtstmTrans has correct fields for transition specific models", {
+  m <- create_IndivCtstmTrans(msfit_list, input_data = msfit_list_data, 
+                              trans_mat = tmat_ebmt4, 
+                              clock = "reset", n = n_samples)
+  expect_equal(m$clock, "reset")
+  expect_equal(m$trans_mat, tmat_ebmt4)
+  expect_equal(m$params[[1]]$n_samples, n_samples)
+  
+  m <- create_IndivCtstmTrans(msfit_list, input_data = msfit_list_data, 
+                              trans_mat = tmat_ebmt4, 
+                              clock = "forward", n = n_samples)
+  expect_equal(m$clock, "forward")
+})
+
+# Joint model
+transitions <- create_trans_dt(tmat_ebmt4)
+transitions[, trans := transition_id]
+hesim_dat$transitions <- transitions
+msfit_data <- expand(hesim_dat, by = c("strategies", "patients", "transitions"))
+
+test_that("create_IndivCtstmTrans has correct fields for joint model", {
+  m <- create_IndivCtstmTrans(msfit, input_data = msfit_data, 
+                              trans_mat = tmat_ebmt4, 
+                              clock = "reset", n = n_samples)
+  expect_equal(m$clock, "reset")
+  expect_equal(m$trans_mat, tmat_ebmt4)
+  expect_equal(m$params$n_samples, n_samples)
+  
+  m <- create_IndivCtstmTrans(msfit_cf, input_data = msfit_data, 
+                              trans_mat = tmat_ebmt4, 
+                              clock = "forward", n = n_samples)
+  expect_equal(m$clock, "forward")
+})
+
 # Simulate economic model ------------------------------------------------------
 # Construct economic model
 ## Utility
@@ -142,11 +189,9 @@ drugcostsmod <- create_StateVals(drugcost_tbl, n = n_samples, hesim_data = hesim
 
 ## Transitions
 ### With transition specific survival models
-msfit_list_data <- expand(hesim_dat)
 tmat <- rbind(c(NA, 1, 2),
               c(NA, NA, 3),
               c(NA, NA, NA))
-
 test_that("IndivCtstmTrans - transition specific", {
   mstate_list <- create_IndivCtstmTrans(msfit_list, input_data = msfit_list_data, 
                                         trans_mat = tmat,
@@ -204,11 +249,6 @@ test_that("IndivCtstmTrans - transition specific", {
 })  
 
 ### With a joint model
-transitions <- create_trans_dt(tmat_ebmt4)
-transitions[, trans := transition_id]
-hesim_dat$transitions <- transitions
-msfit_data <- expand(hesim_dat, by = c("strategies", "patients", "transitions"))
-
 test_that("IndivCtstmTrans - joint", {
   mstate <- create_IndivCtstmTrans(msfit, input_data = msfit_data, 
                                    trans_mat = tmat_ebmt4,
